.. _integration:

******************************************************
Integration and Folding (`baseband_tasks.integration`)
******************************************************

`~baseband_tasks.integration` contains tasks for integration, folding, and
creating pulse stacks.  Helpers to create phase functions are in the
:ref:`phases` module.

.. _integration_api:

Reference/API
=============

.. automodapi:: baseband_tasks.integration
   :no-inherited-members:
